Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJoshua Leung <aligorith@gmail.com>2010-04-02 16:02:39 +0400
committerJoshua Leung <aligorith@gmail.com>2010-04-02 16:02:39 +0400
commit341843bc54119e5bc9563a02f332ce228da161bc (patch)
tree7fa13010f2abd0091b1551bb78ae9b72e54e9fa9 /source/blender/editors/space_nla
parentfb4b16b799ca514a9cc30d19f8e2274bf912246d (diff)
Batch renaming some keyframe editing internals in preparation for more generic keyframe editing API, allowing more niceties...
Diffstat (limited to 'source/blender/editors/space_nla')
-rw-r--r--source/blender/editors/space_nla/nla_edit.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/source/blender/editors/space_nla/nla_edit.c b/source/blender/editors/space_nla/nla_edit.c
index 706dcf49c4f..eeb8fc5e696 100644
--- a/source/blender/editors/space_nla/nla_edit.c
+++ b/source/blender/editors/space_nla/nla_edit.c
@@ -1239,10 +1239,10 @@ void NLA_OT_action_sync_length (wmOperatorType *ot)
/* Reset the scaling of the selected strips to 1.0f */
/* apply scaling to keyframe */
-static short bezt_apply_nlamapping (BeztEditData *bed, BezTriple *bezt)
+static short bezt_apply_nlamapping (KeyframeEditData *ked, BezTriple *bezt)
{
- /* NLA-strip which has this scaling is stored in bed->data */
- NlaStrip *strip= (NlaStrip *)bed->data;
+ /* NLA-strip which has this scaling is stored in ked->data */
+ NlaStrip *strip= (NlaStrip *)ked->data;
/* adjust all the times */
bezt->vec[0][0]= nlastrip_get_frame(strip, bezt->vec[0][0], NLATIME_CONVERT_MAP);
@@ -1261,7 +1261,7 @@ static int nlaedit_apply_scale_exec (bContext *C, wmOperator *op)
bAnimListElem *ale;
int filter;
- BeztEditData bed;
+ KeyframeEditData ked;
/* get editor data */
if (ANIM_animdata_get_context(C, &ac) == 0)
@@ -1272,7 +1272,7 @@ static int nlaedit_apply_scale_exec (bContext *C, wmOperator *op)
ANIM_animdata_filter(&ac, &anim_data, filter, ac.data, ac.datatype);
/* init the editing data */
- memset(&bed, 0, sizeof(BeztEditData));
+ memset(&ked, 0, sizeof(KeyframeEditData));
/* for each NLA-Track, apply scale of all selected strips */
for (ale= anim_data.first; ale; ale= ale->next) {
@@ -1295,8 +1295,8 @@ static int nlaedit_apply_scale_exec (bContext *C, wmOperator *op)
}
/* setup iterator, and iterate over all the keyframes in the action, applying this scaling */
- bed.data= strip;
- ANIM_animchanneldata_keys_bezier_loop(&bed, strip->act, ALE_ACT, NULL, bezt_apply_nlamapping, calchandles_fcurve, 0);
+ ked.data= strip;
+ ANIM_animchanneldata_keyframes_loop(&ked, strip->act, ALE_ACT, NULL, bezt_apply_nlamapping, calchandles_fcurve, 0);
/* clear scale of strip now that it has been applied,
* and recalculate the extents of the action now that it has been scaled